Don't add type names for enums; they're never used in LLVM IR.

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@129894 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CodeGenTypes.h b/lib/CodeGen/CodeGenTypes.h
index a0e1caa..dc383cb 100644
--- a/lib/CodeGen/CodeGenTypes.h
+++ b/lib/CodeGen/CodeGenTypes.h
@@ -101,10 +101,10 @@
   /// used to handle cyclic structures properly.
   void HandleLateResolvedPointers();
 
-  /// addTagTypeName - Compute a name from the given tag decl with an optional
-  /// suffix and name the given LLVM type using it.
-  void addTagTypeName(const TagDecl *TD, const llvm::Type *Ty,
-                      llvm::StringRef suffix);
+  /// addRecordTypeName - Compute a name from the given record decl with an
+  /// optional suffix and name the given LLVM type using it.
+  void addRecordTypeName(const RecordDecl *RD, const llvm::Type *Ty,
+                         llvm::StringRef suffix);
 
 public:
   CodeGenTypes(ASTContext &Ctx, llvm::Module &M, const llvm::TargetData &TD,